;; Generated package description from minibuffer-line.el  -*- no-byte-compile: t -*-
(define-package "minibuffer-line" "0.1.0.20201201.162346" "Display status info in the minibuffer window" 'nil :url "https://elpa.gnu.org/packages/minibuffer-line.html" :authors '(("Stefan Monnier" . "monnier@iro.umontreal.ca")) :maintainer '("Stefan Monnier" . "monnier@iro.umontreal.ca"))
